@@ -39,8 +39,8 @@ ICoClustModel::ICoClustModel( ModelParameters const& Mparam)
                             , m_Rjl_(Mparam_.nbCol_, Mparam_.nbcolclust_, 1./Mparam_.nbcolclust_)
                             , m_Tiktemp_(m_Tik_)
                             , m_Rjltemp_(m_Rjl_)
-                            , v_Tk_(Mparam_.nbrowclust_)
-                            , v_Rl_(Mparam_.nbcolclust_)
+                            , v_Tk_(Mparam_.nbrowclust_, 1.)
+                            , v_Rl_(Mparam_.nbcolclust_, 1.)
                             , v_Piek_(Mparam_.nbrowclust_, 1./Mparam_.nbrowclust_)
                             , v_Rhol_(Mparam_.nbcolclust_, 1./Mparam_.nbcolclust_)
                             , v_logPiek_(v_Piek_.log())
