@@ -40,68 +40,68 @@ bool XStrategyforSEMAlgo::run()
   STK::Real Lmax = -RealMax,L1 = -RealMax,Lcurrent;
   int ntry_empty=0;
   bool non_empty = false;
-  for ( int itry = 0; itry < strategyParam_.nbtry_; ++itry) {
+  for ( int itry = 0; itry < strategyParam_.nbtry_; ++itry)
+  {
     non_empty = false;
     L1 = -RealMax;
-    for ( int ixem = 0; ixem < strategyParam_.nbxem_; ++ixem) {
+    for ( int ixem = 0; ixem < strategyParam_.nbxem_; ++ixem)
+    {
       ntry_empty = -1;
       p_Model_->setEmptyCluster(true);
-      while(p_Model_->isEmptyCluster()&&ntry_empty<100)
+      while(p_Model_->isEmptyCluster() && ntry_empty<strategyParam_.nbinitmax_)
       {
         if (p_Init_->run())
         {
-            for ( int itr = 0; itr < strategyParam_.nbiter_xem_; ++itr)
-            {
-              if (p_Algo_->run()) {
-                Lcurrent = p_Model_->estimateLikelihood();
-                if(Lcurrent>=L1)
-                {
-                  non_empty = true;
-                  L1 = Lcurrent;
-                  p_Model_->modifyThetaStart();
-                }
+          for ( int itr = 0; itr < strategyParam_.nbiter_xem_; ++itr)
+          {
+            if (p_Algo_->run()) {
+              Lcurrent = p_Model_->computeLnLikelihood();
+              if(Lcurrent>=L1)
+              {
+                non_empty = true;
+                L1 = Lcurrent;
+                p_Model_->modifyTheta();
               }
             }
+          }
         }
         ntry_empty++;
       }
     }
-
-    if(non_empty){
-      p_Model_->copyThetaStart();
-      Lcurrent = p_Model_->estimateLikelihood();
-      if(!p_Model_->isEmptyCluster()&&Lcurrent>Lmax)
+    if (!non_empty) continue;
+    // start XEM iterations
+    p_Model_->copyTheta();
+    p_Model_->modifyTheta(); // initialize Theta max values to start values
+    Lcurrent = p_Model_->computeLnLikelihood();
+    if(!p_Model_->isEmptyCluster()&&Lcurrent>Lmax)
+    {
+      Lmax = Lcurrent;
+      p_Model_->modifyTheta();
+    }
+    for ( int itr = 0; itr < strategyParam_.nbiter_XEM_; ++itr)
+    {
+      if (p_Algo_->run())
       {
-        Lmax = Lcurrent;
-        p_Model_->modifyThetaMax();
-      }
-        for ( int itr = 0; itr < strategyParam_.nbiter_XEM_; ++itr)
+        Lcurrent = p_Model_->computeLnLikelihood();
+        if(Lcurrent>Lmax)
         {
-          if (p_Algo_->run()) {
-            Lcurrent = p_Model_->estimateLikelihood();
-            if(Lcurrent>Lmax)
-            {
-              Lmax = Lcurrent;
-              p_Model_->modifyThetaMax();
-            }
-          }
+          Lmax = Lcurrent;
+          p_Model_->modifyTheta();
         }
+      }
     }
-
   }
+  // check if al try failed
   if(non_empty)
   {
-    p_Model_->copyThetaMax();
+    p_Model_->copyTheta();
     p_Model_->finalizeOutput();
 #ifdef COVERBOSE
     std::cout<<"Strategy over.\n";
     p_Model_->consoleOut();
     std::cout<<"\nLmax:"<<Lmax<<"\n";
 #endif
-    return true;
-  }
-  else
-  {
-    return false;
+    return !p_Model_->isEmptyCluster();
   }
+  return false;
 }
